@@ -2,6 +2,7 @@
 // sys/bit.h: Bit Vector Library, system level
 // ============================================================================
 //
+// 09/25/04 RD        fixed two syntax errors (too many closing parentheses)
 // 03/06/03 RD  made members of class __bitslice public so that they
 //              can be accessed by classes _specc::bufbus_elem and
 //              _specc::sigbus_elem
@@ -74,7 +75,9 @@
 #define _BITCHUNK_SIZE          ((int)((sizeof(_bit::chunk)*CHAR_BIT)))
 
 // Size of the complete bit vector class (including virtual table pointer, 
-// same as sizeof(bit<len>) but at runtime)
+// same as sizeof(bit<len>) but at runtime).
+// This macro only gives a lower bound for the real size as it does not
+// take alignment issues into account!
 // ## Determine base size during compile time through test program
 //    instead of hard-coding size of virtual table pointer.
 #define _SIZEOFBITCLASS(len)    (_SIZEOFBIT(len)+sizeof(void*))
@@ -906,7 +909,7 @@ inline _bit& _bit::set(long i) {
 #ifndef _RSH_IS_SIGN_EXTENDING
   bool neg = (i < 0);
 #endif
-  int j; for (j = 0; j < _BITCHUNKS(_MINLEN(len,(int)_BITLEN_LONG))); j++) {
+  int j; for (j = 0; j < _BITCHUNKS(_MINLEN(len,(int)_BITLEN_LONG)); j++) {
     vec[j].uval = i;
     i >>= _BITCHUNK_SIZE;
   }
@@ -921,7 +924,7 @@ inline _bit& _bit::set(long i) {
 }
 
 inline _bit& _bit::set(unsigned long i) {
-  int j; for (j = 0; j < _BITCHUNKS(_MINLEN(len,(int)_BITLEN_ULONG))); j++) {
+  int j; for (j = 0; j < _BITCHUNKS(_MINLEN(len,(int)_BITLEN_ULONG)); j++) {
     vec[j].uval = i;
     i >>= _BITCHUNK_SIZE;
   }
